m3_floating_toolbar_preview library

Constants

kPreviewSize → const Size
Size of the preview viewport used by every preview.

Functions

m3FloatingToolbarAllIconsPreview() → Widget
m3FloatingToolbarAllIconsWithTextPreview() → Widget
m3FloatingToolbarBottomCenterPreviewWrapper(Widget child) → Widget
m3FloatingToolbarEndCenterPreviewWrapper(Widget child) → Widget
m3FloatingToolbarLabelsPreview() → Widget
Preview where every action is labeled and only the selected one adds an icon.
m3FloatingToolbarOverflowMenuPreview() → Widget
Preview of an email toolbar that moves overflow actions into a menu.
m3FloatingToolbarPreview() → Widget
Basic preview where tapping an action selects it.
m3FloatingToolbarThemeColorsPreview() → Widget
Preview that themes the toolbar from a selection of bright colors.
m3FloatingToolbarVerticalPreview() → Widget
m3FloatingToolbarVerticalWithFabPreview() → Widget
m3FloatingToolbarWithFabPreview() → Widget